@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -75,7 +75,7 @@ public:
 
 void InsertHtmlDialogPrivate::_k_slotTextChanged()
 {
-    okButton->setEnabled(!editor->toPlainText().isEmpty());
+    okButton->setEnabled(!editor->document()->isEmpty());
 }
 
 InsertHtmlDialog::InsertHtmlDialog(QWidget *parent)
