@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -34,7 +34,7 @@ class KPIMTEXTEDIT_EXPORT InsertHtmlDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit InsertHtmlDialog(QWidget *parent = Q_NULLPTR);
+    explicit InsertHtmlDialog(QWidget *parent = nullptr);
     ~InsertHtmlDialog();
     QString html() const;
 
