@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -30,7 +30,7 @@
 using namespace KPIMTextEdit;
 TextMessageIndicator::TextMessageIndicator(QWidget *parent)
     : QWidget(parent),
-      mTimer(Q_NULLPTR),
+      mTimer(nullptr),
       mLineSpacing(0)
 {
     setObjectName(QStringLiteral("TextMessageIndicator"));
