@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -16,8 +16,8 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-
 #include "plaintexteditor.h"
+#include "helper_p.h"
 #include "texteditor/commonwidget/textmessageindicator.h"
 #include <KIO/KUriFilterSearchProviderActions>
 #include <KLocalizedString>
@@ -40,7 +40,6 @@
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QTextDocumentFragment>
-#include <QShortcut>
 #include <QScrollBar>
 #include <QApplication>
 #include <QClipboard>
@@ -60,8 +59,8 @@ public:
         : q(qq),
           mTextIndicator(new KPIMTextEdit::TextMessageIndicator(q)),
           webshortcutMenuManager(new KIO::KUriFilterSearchProviderActions(q)),
-          richTextDecorator(Q_NULLPTR),
-          speller(Q_NULLPTR),
+          richTextDecorator(nullptr),
+          speller(nullptr),
           mInitialFontSize(0),
           customPalette(false),
           activateLanguageMenu(true)
@@ -130,7 +129,7 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
         if (!isReadOnly()) {
             QList<QAction *> actionList = popup->actions();
             enum { UndoAct, RedoAct, CutAct, CopyAct, PasteAct, ClearAct, SelectAllAct, NCountActs };
-            QAction *separatorAction = Q_NULLPTR;
+            QAction *separatorAction = nullptr;
             const int idx = actionList.indexOf(actionList[SelectAllAct]) + 1;
             if (idx < actionList.count()) {
                 separatorAction = actionList.at(idx);
@@ -180,16 +179,16 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
                     QActionGroup *languagesGroup = new QActionGroup(languagesMenu);
                     languagesGroup->setExclusive(true);
 
-                    QMapIterator<QString, QString> i(d->speller->availableDictionaries());
 
                     QString defaultSpellcheckingLanguage = spellCheckingLanguage();
                     if (defaultSpellcheckingLanguage.isEmpty()) {
                         //TODO fix default value
                         defaultSpellcheckingLanguage = d->speller->defaultLanguage();
                     }
-                    while (i.hasNext()) {
-                        i.next();
 
+                    QMapIterator<QString, QString> i(d->speller->availableDictionaries());
+                    while(i.hasNext()) {
+                        i.next();
                         QAction *languageAction = languagesMenu->addAction(i.key());
                         languageAction->setCheckable(true);
                         languageAction->setChecked(defaultSpellcheckingLanguage == i.value());
@@ -216,6 +215,7 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
             d->webshortcutMenuManager->setSelectedText(selectedText);
             d->webshortcutMenuManager->addWebShortcutsToMenu(popup);
         }
+
         addExtraMenuEntry(popup, event->pos());
         popup->exec(event->globalPos());
 
@@ -357,11 +357,11 @@ void PlainTextEditor::slotCheckSpelling()
         backgroundSpellCheck->changeLanguage(d->spellCheckingLanguage);
     }
     if (!d->ignoreSpellCheckingWords.isEmpty()) {
-        Q_FOREACH (const QString &word, d->ignoreSpellCheckingWords) {
+        for (const QString &word : qAsConst(d->ignoreSpellCheckingWords)) {
             backgroundSpellCheck->speller().addToSession(word);
         }
     }
-    Sonnet::Dialog *spellDialog = new Sonnet::Dialog(backgroundSpellCheck, Q_NULLPTR);
+    Sonnet::Dialog *spellDialog = new Sonnet::Dialog(backgroundSpellCheck, nullptr);
     backgroundSpellCheck->setParent(spellDialog);
     spellDialog->setAttribute(Qt::WA_DeleteOnClose, true);
     connect(spellDialog, &Sonnet::Dialog::replace, this, &PlainTextEditor::slotSpellCheckerCorrected);
@@ -653,7 +653,7 @@ Sonnet::Highlighter *PlainTextEditor::highlighter() const
     if (d->richTextDecorator) {
         return d->richTextDecorator->highlighter();
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -669,7 +669,7 @@ void PlainTextEditor::addIgnoreWordsToHighLighter()
     }
     if (d->richTextDecorator) {
         Sonnet::Highlighter *_highlighter = d->richTextDecorator->highlighter();
-        Q_FOREACH (const QString &word, d->ignoreSpellCheckingWords) {
+        for (const QString &word : qAsConst(d->ignoreSpellCheckingWords)) {
             _highlighter->ignoreWord(word);
         }
     }
@@ -735,7 +735,7 @@ void PlainTextEditor::updateHighLighter()
 void PlainTextEditor::clearDecorator()
 {
     delete d->richTextDecorator;
-    d->richTextDecorator = Q_NULLPTR;
+    d->richTextDecorator = nullptr;
 }
 
 void PlainTextEditor::createHighlighter()
