@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,7 +25,7 @@ class TextToSpeechConfigGui : public QWidget
 {
     Q_OBJECT
 public:
-    explicit TextToSpeechConfigGui(QWidget *parent = Q_NULLPTR);
+    explicit TextToSpeechConfigGui(QWidget *parent = nullptr);
     ~TextToSpeechConfigGui();
 
 };
